# Independent Validation
This package implements an alternative to cross validation called independent validation.

For more details on this method see the original paper: [
Independent Validation as a Validation Method for Classification
](https://qcmb.psychopen.eu/index.php/qcmb/article/view/12069)

This package was developed at the [Thomas Bayes Institute](https://thomasbayesinstitute.org/en/)


